#ifndef NT2_INCLUDE_FUNCTIONS_MINMOD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MINMOD_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/minmod.hpp>

#endif
